﻿using System;
using System.Collections.Generic;
using System.Linq;
using BusinessModel;
using Interfaces.Services;

namespace DataRepository
{
public class Repository : BaseRepository<ReengineeringEntities>, IRepository
{
  private List<Person> _personCache;
  private List<string> _stateCache;

  public Repository()
  {
    Initialize();
  }


  /// <summary>
  /// Returns a list of all states the business provides services in
  /// </summary>
  public List<string> GetValidStatesForCustomer(Guid pCustomerId)
  {
    return _stateCache;
  }

  /// <summary>
  /// Gets the person specified by the given ID
  /// </summary>
  public Person GetPerson(int id)
  {
    var x = (from p in _personCache
              where p.Id == id
              select p).SingleOrDefault();
    return x;
  }

  /// <summary>
  /// Gets a list of the people in the system
  /// </summary>
  public List<Person> GetPeople()
  {
    return _personCache;
  }


  /// <summary>
  /// This method is only here for demo purposes.  In a real app
  /// this would not exist and data would be pulled from the DB.
  /// </summary>
  private void Initialize()
  {
    _personCache = new List<Person>();

    var p = new Person();
    p.Id = 1;
    p.FirstName = "Brad";
    p.LastName = "Irby";
    p.BirthDate = DateTime.Parse("4/7/1964");
    p.Email = "brad@bradirby.com";
    p.DateJoined = DateTime.Parse("1/1/2012");
    _personCache.Add(p);

    p = new Person();
    p.Id = 2;
    p.FirstName = "Joan";
    p.LastName = "Murray";
    p.BirthDate = DateTime.Parse("1/1/1990");
    p.Email = "Joan@JoansCompany.com";
    p.DateJoined = DateTime.Parse("2/1/2012");
    _personCache.Add(p);

    p = new Person();
    p.Id = 3;
    p.FirstName = "Joey";
    p.LastName = "EBright";
    p.BirthDate = DateTime.Parse("1/1/1950");
    p.Email = "Joey@JoeysCompany.com";
    p.DateJoined = DateTime.Parse("3/1/2012");
    _personCache.Add(p);

    p = new Person();
    p.Id = 4;
    p.FirstName = "Marcela";
    p.LastName = "Chauvet";
    p.BirthDate = DateTime.Today.AddYears(-21);  //forever 21
    p.Email = "Marcela@MarcelasCompany.com";
    p.DateJoined = DateTime.Parse("4/1/2012");
    _personCache.Add(p);

    _stateCache = new List<string>();
    _stateCache.Add("California");
    _stateCache.Add("Florida");
    _stateCache.Add("New York");

  }
}
}