﻿using System;

namespace DataTransferObjects
{
  public interface IObjectManagerReference<T> where T : class
  {
    /// <summary>
    /// The object to be referenced
    /// </summary>
    T Object { get; }

    /// <summary>
    /// Flag indicating whether this object
    /// is still alive (has not been garbage
    /// collected yet) This is always true
    /// for a strong reference.
    /// </summary>
    bool IsAlive { get; }

    /// <summary>
    /// Name of the object this class references.
    /// This is use for retrieval later and must
    /// be unique.
    /// </summary>
    string Name { get; }
  }

  public class StrongReferenceDto<T> : IObjectManagerReference<T> where T : class
  {
    public virtual T Object { get; internal set; }
    public virtual bool IsAlive { get { return true; } }
    public string Name { get; internal set; }
    public StrongReferenceDto(T pObject, string pName)
    {
      if (pObject == null) throw new ArgumentNullException("pObject");
      Object = pObject;
      Name = pName;
    }
  }

  public class WeakReferenceDto<T> : IObjectManagerReference<T> where T : class
  {
    private WeakReference _reference;

    public string Name { get; internal set; }
    public T Object
    {
      get { return _reference.Target as T; }
      internal set { _reference = new WeakReference(value); }
    }

    public bool IsAlive
    {
      get { return _reference.IsAlive; }
    }

    public WeakReferenceDto(T pObject, string pName)
    {
      if (pObject == null) throw new ArgumentNullException("pObject");
      Object = pObject;
      Name = pName;
    }
  }
}