﻿using System;
using System.Collections.Generic;
using System.Text;
using Interfaces;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using Moq;
using Services;

namespace ServicesUnitTests
{
  [TestClass]
  public class CommandDispatcherServiceUnitTest
	{
		private CommandDispatcherService<string> _svc;
		private string _testCommandKey;
			
		[TestInitialize]
		public void Setup()
		{
			_testCommandKey = "testCommand";
			_svc = new CommandDispatcherService<string>();
		}

    [TestMethod]
		public void Setup_Succeeds()
		{
			Assert.IsTrue(true);
		}

    [TestMethod]
		public void Constructor_WhenCalled_InitializesCommandList()
		{
			Assert.IsNotNull(_svc._executableCommands);
		}

    [TestMethod]
		[ExpectedException(typeof(ArgumentNullException))]
		public void ExecuteCommand_WhenCalledWithNullKey_ThrowsException()
		{
			_svc.ExecuteCommand(null, null);
		}

    [TestMethod]
		public void ExecuteCommand_WhenCalledWithValidCommand_ExecutesCommand()
		{
			var cmd = new Mock<IDispatchedCommand<string>>();
			var wasCalled = false;
			cmd.Setup(c => c.CommandKey).Returns(_testCommandKey);
			cmd.Setup(c => c.Execute(It.IsAny<object>())).Callback(() => wasCalled = true);
			_svc.AddCommand(cmd.Object);

			_svc.ExecuteCommand(_testCommandKey, null);

			Assert.IsTrue(wasCalled);
		}

    [TestMethod]
		[ExpectedException(typeof(ArgumentNullException))]
		public void AddCommand_WhenCalledWithNullCommand_ThrowsException()
		{
			_svc.AddCommand(null);
		}

    [TestMethod]
		public void AddCommand_WhenCalled_AddsCommandToList()
		{
			var cmd = new Mock<IDispatchedCommand<string>>();
			cmd.Setup(c => c.CommandKey).Returns(_testCommandKey);

			_svc.AddCommand(cmd.Object);

			Assert.AreEqual(1, _svc._executableCommands.Count);
		}

    [TestMethod]
		public void ClearCommand_WhenCalled_ClearsCommandList()
		{
			var cmd = new Mock<IDispatchedCommand<string>>();
			cmd.Setup(c => c.CommandKey).Returns(_testCommandKey);
			_svc.AddCommand(cmd.Object);

			_svc.ClearCommands();

			Assert.AreEqual(0, _svc._executableCommands.Count);
		}


	}


}
