﻿using System.Windows;
using Controllers;
using DataRepository;
using Infrastructure;
using Interfaces.Controllers;
using Interfaces.Services;
using Interfaces.Views;
using Microsoft.Practices.Prism.UnityExtensions;
using Microsoft.Practices.Unity;
using Resources;
using Services;
using Views_Winforms;

namespace Shell
{

  public class BootStrapperWinforms : UnityBootstrapper
  {

    /// <summary>
    /// This is the entry point into our custom bootstrapper
    /// and is called by the base
    /// </summary>
    protected override void ConfigureContainer()
    {
      base.ConfigureContainer();
      ServiceLocator.Container = Container;

      RegisterControlsAndControllers(Container);
      RegisterServices(Container);
    }

    /// <summary>
    /// Registers all services for the application
    /// </summary>
    protected void RegisterServices(IUnityContainer container)
    {
      //Register this service as a singleton by using the 
      //ContainerControlledLifetimeManager parameter
      container.RegisterType<ILogger, Logger>(
        new ContainerControlledLifetimeManager());
      container.RegisterType<IApplicationSession, ApplicationSession>(
        new ContainerControlledLifetimeManager());
      container.RegisterType<IMessageAggregator, MessageAggregator>(
        new ContainerControlledLifetimeManager());
      container.RegisterType<IRepository, Repository>(
        new ContainerControlledLifetimeManager());
      container.RegisterType<ISecurityService, SecurityService>(
        new ContainerControlledLifetimeManager());
      container.RegisterType<IResourceProvider, ResourceProvider>(
        new ContainerControlledLifetimeManager());
      container.RegisterType<IDialogService, DialogService>(
        new ContainerControlledLifetimeManager());

      //in Winforms we must register our own region manager
      //in WPF this is done for us by the bootstrapper
      container.RegisterType<IWinformsRegionManager, WinformsRegionManager>(
        new ContainerControlledLifetimeManager());
    }

    /// <summary>
    /// Registers the views and controllers.
    /// </summary>
    protected void RegisterControlsAndControllers(IUnityContainer container)
    {
      //there should only be one navigation view so register
      //as a singleton
      container.RegisterType<INavigationView, NavigationView>(
        new ContainerControlledLifetimeManager());
      container.RegisterType<INavigationViewController, NavigationViewController>(
        new ContainerControlledLifetimeManager());

      //we should be able to create as many data entry views as we like
      //so register as normal (i.e. not a singleton)
      container.RegisterType<IDataEntryView, DataEntryView>();
      container.RegisterType<IDataEntryViewController, DataEntryViewController>();

      container.RegisterType<IDataGridView, DataGridView>();
      container.RegisterType<IDataGridViewController, DataGridViewController>();

      //our shell should also be a singleton
      container.RegisterType<IShellView, ShellView>(
        new ContainerControlledLifetimeManager());
      container.RegisterType<IShellFormController, ShellFormController>(
        new ContainerControlledLifetimeManager());
    }



    /// <summary>
    /// Returns the controller for the shell so Program.cs
    /// can run the app shell.  This is Winforms specific
    /// and should be replaced in the WPF version
    /// </summary>
    public IShellFormController ShellController
    {
      get
      {
        var x = Container.Resolve<IShellFormController>();
        return x;
      }
    }

    /// <summary>
    /// This is a requirement by the UnityBootstrapper because
    /// it was built with WPF in mind.  For Winforms
    /// this makes no sense so we just return null.
    /// </summary>
    protected override DependencyObject CreateShell()
    {
      return null;
    }
  }
}