﻿using Infrastructure;
using Interfaces.ViewModels;
using Interfaces.Views;

namespace ViewModels
{
  public class BaseViewModel<T> : IBaseViewModel<T> where T : IBaseView
  {

    protected string _regionName;

    public BaseViewModel()
    {
      View = ServiceLocator.Resolve<T>();
    }

    /// <summary>
    /// The view this controller is managing
    /// </summary>
    public T View { get; protected set; }

    /// <summary>
    /// Assigns to the controller the proper region 
    /// to use for displaying its view
    /// </summary>
    public void SetViewRegion(string pRegionName)
    {
      _regionName = pRegionName;
      View.SetRegion(pRegionName);
    }

    /// <summary>
    /// Activates the view so it displays on the screen
    /// </summary>
    public virtual void Activate()
    {
      View.SetActive();
    }

    /// <summary>
    /// Deactivates the view so another view can become active
    /// </summary>
    public virtual void Deactivate()
    {
      View.SetInActivate();
    }
  }
}