﻿using System;
using System.Windows.Input;
using DataTransferObjects;
using Infrastructure;
using Interfaces.Services;
using Interfaces.ViewModels;
using Interfaces.Views;
using Microsoft.Practices.Prism.Commands;

namespace ViewModels
{
  public class NavigationViewModel : BaseViewModel<INavigationView>, INavigationViewModel
  {
    /// <summary>
    /// Button text for the detail view button
    /// </summary>
    public string ShowDetailViewButtonText { get; set; }

    /// <summary>
    /// Button text for the Grid view button
    /// </summary>
    public string ShowGridViewButtonText { get; set; }

    /// <summary>
    /// Name of the region where the detail and grid
    /// should register themselves
    /// </summary>
    public string WorkspaceRegionName { get; set; }

    /// <summary>
    /// Click handler for the detail view button
    /// </summary>
    public ICommand ShowDetailView { get; set; }

    /// <summary>
    /// click handler for the grid view button
    /// </summary>
    public ICommand ShowGridView { get; set; }

    private IDataEntryViewModel DataEntryVM
    {
      get
      {
        if (_dataEntryVM == null)
        {
          if (string.IsNullOrEmpty(WorkspaceRegionName))
            throw new ArgumentNullException("WorkspaceRegionName");
          _dataEntryVM = ServiceLocator.Resolve<IDataEntryViewModel>();
          _dataEntryVM.SetViewRegion(WorkspaceRegionName);
        }
        return _dataEntryVM;
      }
    }
    private IDataEntryViewModel _dataEntryVM;

    private IDataGridViewModel DataGridVM
    {
      get
      {
        if (_dataGridVM == null)
        {
          if (string.IsNullOrEmpty(WorkspaceRegionName))
            throw new ArgumentNullException("WorkspaceRegionName");
          _dataGridVM = ServiceLocator.Resolve<IDataGridViewModel>();
          _dataGridVM.SetViewRegion(WorkspaceRegionName);
        }
        return _dataGridVM;
      }
    }
    private IDataGridViewModel _dataGridVM;


    private void OnShowDetailView(string obj)
    {
      var msgSvc = ServiceLocator.Resolve<IMessageAggregator>();
      msgSvc.GetEvent<StatusMessage>().Publish(new StatusMessageDto("Data Entry Opened"));
      DataEntryVM.Activate();
    }

    private void OnShowGridView(string obj)
    {
      var msgSvc = ServiceLocator.Resolve<IMessageAggregator>();
      msgSvc.GetEvent<StatusMessage>().Publish(new StatusMessageDto("Grid Opened"));
      DataGridVM.Activate();
    }

    public NavigationViewModel()
    {
      ShowDetailView = new DelegateCommand<string>(OnShowDetailView);
      ShowGridView = new DelegateCommand<string>(OnShowGridView);

      ShowDetailViewButtonText = "Show Detail View";
      ShowGridViewButtonText = "Show Grid View";
      View.DataContext = this;
    }
  }
}