﻿using System.Windows.Controls;
using Infrastructure;
using Interfaces.Views;
using Microsoft.Practices.Prism.Regions;

namespace Views_WPF
{
	public class BaseView : UserControl, IBaseView
	{
    protected IRegionManager RegionMgr
    {
      get
      {
        return _regionMgr ?? (
          _regionMgr = ServiceLocator.Resolve<IRegionManager>());
      }
    }
    private IRegionManager _regionMgr;

	  protected string _regionName;


		/// <summary>
		/// Assigns the proper region.  Use the RegionConstants global static var for region names
		/// </summary>
		public void SetRegion(string pRegionName)
		{
		  _regionName = pRegionName;
      RegionMgr.Regions[_regionName].Add(this);
		}

		/// <summary>
		/// This activates the given view in the region, displaying the view.
		/// </summary>
		public void SetActive()
		{
      RegionMgr.Regions[_regionName].Activate(this);
    }

		/// <summary>
		/// Makes this view invisible, but leaves it registered for future activation
		/// </summary>
		public void SetInActivate()
		{
      RegionMgr.Regions[_regionName].Deactivate(this);
    }
	}
}
